"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.VictoryBoxPlot = void 0;
var _react = _interopRequireDefault(require("react"));
var _victoryCore = require("victory-core");
var _helperMethods = require("./helper-methods");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
const fallbackProps = {
  width: 450,
  height: 300,
  padding: {
    top: 20,
    right: 20,
    bottom: 20,
    left: 20
  }
};
const defaultData = [{
  x: 1,
  min: 5,
  q1: 7,
  median: 12,
  q3: 18,
  max: 20
}, {
  x: 2,
  min: 2,
  q1: 5,
  median: 8,
  q3: 12,
  max: 15
}];
const options = {
  components: [{
    name: "min"
  }, {
    name: "minLabels"
  }, {
    name: "max"
  }, {
    name: "maxLabels"
  }, {
    name: "median"
  }, {
    name: "medianLabels"
  }, {
    name: "q1"
  }, {
    name: "q1Labels"
  }, {
    name: "q3"
  }, {
    name: "q3Labels"
  }, {
    name: "parent",
    index: "parent"
  }]
};

// eslint-disable-next-line @typescript-eslint/no-empty-interface

class VictoryBoxPlotBase extends _react.default.Component {
  static animationWhitelist = ["data", "domain", "height", "padding", "style", "width"];
  static displayName = "VictoryBoxPlot";
  static role = "boxplot";
  static defaultTransitions = _victoryCore.DefaultTransitions.discreteTransitions();
  static defaultProps = {
    containerComponent: /*#__PURE__*/_react.default.createElement(_victoryCore.VictoryContainer, null),
    data: defaultData,
    dataComponent: /*#__PURE__*/_react.default.createElement(_victoryCore.Box, null),
    groupComponent: /*#__PURE__*/_react.default.createElement("g", {
      role: "presentation"
    }),
    maxComponent: /*#__PURE__*/_react.default.createElement(_victoryCore.Whisker, null),
    maxLabelComponent: /*#__PURE__*/_react.default.createElement(_victoryCore.VictoryLabel, null),
    medianComponent: /*#__PURE__*/_react.default.createElement(_victoryCore.LineSegment, null),
    medianLabelComponent: /*#__PURE__*/_react.default.createElement(_victoryCore.VictoryLabel, null),
    minComponent: /*#__PURE__*/_react.default.createElement(_victoryCore.Whisker, null),
    minLabelComponent: /*#__PURE__*/_react.default.createElement(_victoryCore.VictoryLabel, null),
    q1Component: /*#__PURE__*/_react.default.createElement(_victoryCore.Box, null),
    q1LabelComponent: /*#__PURE__*/_react.default.createElement(_victoryCore.VictoryLabel, null),
    q3Component: /*#__PURE__*/_react.default.createElement(_victoryCore.Box, null),
    q3LabelComponent: /*#__PURE__*/_react.default.createElement(_victoryCore.VictoryLabel, null),
    samples: 50,
    sortKey: "x",
    sortOrder: "ascending",
    standalone: true,
    theme: _victoryCore.VictoryTheme.grayscale
  };
  static getDomain = _helperMethods.getDomain;
  static getData = _helperMethods.getData;
  static getBaseProps = props => (0, _helperMethods.getBaseProps)(props, fallbackProps);
  static expectedComponents = ["maxComponent", "maxLabelComponent", "medianComponent", "medianLabelComponent", "minComponent", "minLabelComponent", "q1Component", "q1LabelComponent", "q3Component", "q3LabelComponent", "groupComponent", "containerComponent"];
  renderBoxPlot(props) {
    const types = ["q1", "q3", "max", "min", "median"];
    const dataComponents = types.map(type => {
      return this.dataKeys.reduce((validDataComponents, _key, index) => {
        const baseComponent = props[`${type}Component`];
        const componentProps = this.getComponentProps(baseComponent, type, index);
        if (this.shouldRenderDatum(componentProps.datum)) {
          validDataComponents.push( /*#__PURE__*/_react.default.cloneElement(baseComponent, componentProps));
        }
        return validDataComponents;
      }, []);
    }).flat();
    const labelComponents = types.map(type => {
      const components = this.dataKeys.reduce((validComponents, _key, index) => {
        const name = `${type}Labels`;
        const baseComponent = props[`${type}LabelComponent`];
        const labelProps = this.getComponentProps(baseComponent, name, index);
        if (labelProps.text !== undefined && labelProps.text !== null) {
          validComponents.push( /*#__PURE__*/_react.default.cloneElement(baseComponent, labelProps));
        }
        return validComponents;
      }, []);
      return components.filter(Boolean);
    }).flat();
    const children = [...dataComponents, ...labelComponents];
    return this.renderContainer(props.groupComponent, children);
  }

  // Overridden in native versions
  shouldAnimate() {
    return !!this.props.animate;
  }
  shouldRenderDatum(datum) {
    const hasX = !_victoryCore.Helpers.isNil(datum._x);
    const hasY = !_victoryCore.Helpers.isNil(datum._y);
    const hasSummaryStatistics = !_victoryCore.Helpers.isNil(datum._min) && !_victoryCore.Helpers.isNil(datum._max) && !_victoryCore.Helpers.isNil(datum._median) && !_victoryCore.Helpers.isNil(datum._q1) && !_victoryCore.Helpers.isNil(datum._q3);
    return hasSummaryStatistics && (this.props.horizontal ? hasY : hasX);
  }
  render() {
    const {
      animationWhitelist,
      role
    } = VictoryBoxPlot;
    const props = _victoryCore.Helpers.modifyProps(this.props, fallbackProps, role);
    if (this.shouldAnimate()) {
      return this.animateComponent(props, animationWhitelist);
    }
    const children = this.renderBoxPlot(props);
    const component = props.standalone ? this.renderContainer(props.containerComponent, children) : children;
    return _victoryCore.UserProps.withSafeUserProps(component, props);
  }
}
const VictoryBoxPlot = exports.VictoryBoxPlot = (0, _victoryCore.addEvents)(VictoryBoxPlotBase, options);